# Skyborn: A Collection of Tools for My Research

Skyborn is a collection of functions I use in my general research, primarily for personal use.

## System Requirements

**Operating System:** 🖥️ **Windows Only**

Please note that this package is currently developed and tested exclusively for the Windows operating system. Compatibility and functionality on other systems like macOS or Linux are not guaranteed.

## Installation

To install the Skyborn package, you can use pip:

```bash
pip install skyborn
